@@ -1,7 +1,5 @@
-import psutil
 from collections import defaultdict
-
-from discord.ext import commands
+import psutil
 
 from statcord.client import StatcordClient, HEADERS
 
@@ -9,7 +7,7 @@ STAT_ENDPOINT = "https://api.statcord.com/v3/clusters"
 
 
 class StatcordClusterClient(StatcordClient):
-    def __init__(self, bot: commands.Bot, statcord_key: str, cluster_id: str, resource_stats: bool = True) -> None:
+    def __init__(self, bot, statcord_key: str, cluster_id: str, resource_stats: bool = True) -> None:
         super().__init__(bot, statcord_key, resource_stats=resource_stats)
         self.cluster_id = cluster_id
 
